==> Paws-0.41.tar.gz: Paws-0.41/lib/Paws/EC2/DeleteTrafficMirrorSession.pm <==

package Paws::EC2::DeleteTrafficMirrorSession;
  use Moose;
  has DryRun => (is => 'ro', isa => 'Bool');
  has TrafficMirrorSessionId => (is => 'ro', isa => 'Str', required => 1);

  use MooseX::ClassAttribute;

  class_has _api_call => (isa => 'Str', is => 'ro', default => 'DeleteTrafficMirrorSession');
  class_has _returns => (isa => 'Str', is => 'ro', default => 'Paws::EC2::DeleteTrafficMirrorSessionResult');
  class_has _result_key => (isa => 'Str', is => 'ro');
1;

### main pod documentation begin ###

=head1 NAME

Paws::EC2::DeleteTrafficMirrorSession - Arguments for method DeleteTrafficMirrorSession on L<Paws::EC2>

=head1 DESCRIPTION

This class represents the parameters used for calling the method DeleteTrafficMirrorSession on the
L<Amazon Elastic Compute Cloud|Paws::EC2> service. Use the attributes of this class
as arguments to method DeleteTrafficMirrorSession.

You shouldn't make instances of this class. Each attribute should be used as a named argument in the call to DeleteTrafficMirrorSession.

=head1 SYNOPSIS

    my $ec2 = Paws->service('EC2');
    my $DeleteTrafficMirrorSessionResult = $ec2->DeleteTrafficMirrorSession(
      TrafficMirrorSessionId => 'MyString',
      DryRun                 => 1,            # OPTIONAL
    );

    # Results:
    my $TrafficMirrorSessionId =
      $DeleteTrafficMirrorSessionResult->TrafficMirrorSessionId;

    # Returns a L<Paws::EC2::DeleteTrafficMirrorSessionResult> object.

Values for attributes that are native types (Int, String, Float, etc) can passed as-is (scalar values). Values for complex Types (objects) can be passed as a HashRef. The keys and values of the hashref will be used to instance the underlying object.
For the AWS API documentation, see L<https://docs.aws.amazon.com/goto/WebAPI/ec2/DeleteTrafficMirrorSession>

=head1 ATTRIBUTES


=head2 DryRun => Bool

Checks whether you have the required permissions for the action,
without actually making the request, and provides an error response. If
you have the required permissions, the error response is
C<DryRunOperation>. Otherwise, it is C<UnauthorizedOperation>.



=head2 B<REQUIRED> TrafficMirrorSessionId => Str

The ID of the Traffic Mirror session.




=head1 SEE ALSO

This class forms part of L<Paws>, documenting arguments for method DeleteTrafficMirrorSession in L<Paws::EC2>

=head1 BUGS and CONTRIBUTIONS

The source code is located here: L<https://github.com/pplu/aws-sdk-perl>

Please report bugs to: L<https://github.com/pplu/aws-sdk-perl/issues>

=cut

==> Paws-0.43.tar.gz: Paws-0.43/lib/Paws/EC2/DeleteTrafficMirrorSession.pm <==

package Paws::EC2::DeleteTrafficMirrorSession;
  use Moose;
  has DryRun => (is => 'ro', isa => 'Bool');
  has TrafficMirrorSessionId => (is => 'ro', isa => 'Str', required => 1);

  use MooseX::ClassAttribute;

  class_has _api_call => (isa => 'Str', is => 'ro', default => 'DeleteTrafficMirrorSession');
  class_has _returns => (isa => 'Str', is => 'ro', default => 'Paws::EC2::DeleteTrafficMirrorSessionResult');
  class_has _result_key => (isa => 'Str', is => 'ro');
1;

### main pod documentation begin ###

=head1 NAME

Paws::EC2::DeleteTrafficMirrorSession - Arguments for method DeleteTrafficMirrorSession on L<Paws::EC2>

=head1 DESCRIPTION

This class represents the parameters used for calling the method DeleteTrafficMirrorSession on the
L<Amazon Elastic Compute Cloud|Paws::EC2> service. Use the attributes of this class
as arguments to method DeleteTrafficMirrorSession.

You shouldn't make instances of this class. Each attribute should be used as a named argument in the call to DeleteTrafficMirrorSession.

=head1 SYNOPSIS

    my $ec2 = Paws->service('EC2');
    my $DeleteTrafficMirrorSessionResult = $ec2->DeleteTrafficMirrorSession(
      TrafficMirrorSessionId => 'MyTrafficMirrorSessionId',
      DryRun                 => 1,                            # OPTIONAL
    );

    # Results:
    my $TrafficMirrorSessionId =
      $DeleteTrafficMirrorSessionResult->TrafficMirrorSessionId;

    # Returns a L<Paws::EC2::DeleteTrafficMirrorSessionResult> object.

Values for attributes that are native types (Int, String, Float, etc) can passed as-is (scalar values). Values for complex Types (objects) can be passed as a HashRef. The keys and values of the hashref will be used to instance the underlying object.
For the AWS API documentation, see L<https://docs.aws.amazon.com/goto/WebAPI/ec2/DeleteTrafficMirrorSession>

=head1 ATTRIBUTES


=head2 DryRun => Bool

Checks whether you have the required permissions for the action,
without actually making the request, and provides an error response. If
you have the required permissions, the error response is
C<DryRunOperation>. Otherwise, it is C<UnauthorizedOperation>.



=head2 B<REQUIRED> TrafficMirrorSessionId => Str

The ID of the Traffic Mirror session.




=head1 SEE ALSO

This class forms part of L<Paws>, documenting arguments for method DeleteTrafficMirrorSession in L<Paws::EC2>

=head1 BUGS and CONTRIBUTIONS

The source code is located here: L<https://github.com/pplu/aws-sdk-perl>

Please report bugs to: L<https://github.com/pplu/aws-sdk-perl/issues>

=cut
